[gtk+] render: We use CHECKED now, not ACTIVE



commit 57d24f173a4447788b052b76150b85cb8072a521
Author: Benjamin Otte <otte redhat com>
Date:   Tue Oct 21 05:15:37 2014 +0200

    render: We use CHECKED now, not ACTIVE
    
    Update docs and custom rendering of checkmarks and radio buttons

 gtk/gtkrender.c |   12 ++++++------
 1 files changed, 6 insertions(+), 6 deletions(-)
---
diff --git a/gtk/gtkrender.c b/gtk/gtkrender.c
index d33d1fb..5861cb3 100644
--- a/gtk/gtkrender.c
+++ b/gtk/gtkrender.c
@@ -160,7 +160,7 @@ gtk_do_render_check (GtkStyleContext *context,
     }
   else
     {
-      if (flags & GTK_STATE_FLAG_ACTIVE)
+      if (flags & GTK_STATE_FLAG_CHECKED)
         {
           cairo_translate (cr,
                            x + pad, y + pad);
@@ -207,7 +207,7 @@ gtk_do_render_check (GtkStyleContext *context,
  *
  * Renders a checkmark (as in a #GtkCheckButton).
  *
  * The %GTK_STATE_FLAG_ACTIVE state determines whether the check is
  * on or off, and %GTK_STATE_FLAG_INCONSISTENT determines whether it
  * should be marked as undefined.
  *
@@ -323,7 +323,7 @@ gtk_do_render_option (GtkStyleContext *context,
                        line_thickness);
       cairo_fill (cr);
     }
-  if (flags & GTK_STATE_FLAG_ACTIVE)
+  if (flags & GTK_STATE_FLAG_CHECKED)
     {
       pad = thickness + MAX (1, 2 * (exterior_size - 2 * thickness) / 9);
       interior_size = MAX (1, exterior_size - 2 * pad);
@@ -355,7 +355,7 @@ gtk_do_render_option (GtkStyleContext *context,
  * @width: rectangle width
  * @height: rectangle height
  *
  * Renders an option mark (as in a #GtkRadioButton), the %GTK_STATE_FLAG_ACTIVE
  * state will determine whether the option is on or off, and
  * %GTK_STATE_FLAG_INCONSISTENT whether it should be marked as undefined.
  *
@@ -1115,7 +1115,7 @@ gtk_do_render_expander (GtkStyleContext *context,
  * @height: rectangle height
  *
  * Renders an expander (as used in #GtkTreeView and #GtkExpander) in the area
  * defined by @x, @y, @width, @height. The state %GTK_STATE_FLAG_ACTIVE
  * determines whether the expander is collapsed or expanded.
  *
  * Typical expander rendering:
@@ -2163,7 +2163,7 @@ gtk_do_render_activity (GtkStyleContext *context,
  * @height: rectangle height
  *
  * Renders an activity indicator (such as in #GtkSpinner).
  * The state %GTK_STATE_FLAG_ACTIVE determines whether there is
  * activity going on.
  *
  * Since: 3.0
@@ -207,7 +207,7 @@ gtk_do_render_check (GtkStyleContext *context,
  * Renders a checkmark (as in a #GtkCheckButton).
  *
- * The %GTK_STATE_FLAG_ACTIVE state determines whether the check is
+ * The %GTK_STATE_FLAG_CHECKED state determines whether the check is
  * on or off, and %GTK_STATE_FLAG_INCONSISTENT determines whether it
  * should be marked as undefined.
@@ -355,7 +355,7 @@ gtk_do_render_option (GtkStyleContext *context,
  * @height: rectangle height
  *
- * Renders an option mark (as in a #GtkRadioButton), the %GTK_STATE_FLAG_ACTIVE
+ * Renders an option mark (as in a #GtkRadioButton), the %GTK_STATE_FLAG_CHECKED
  * state will determine whether the option is on or off, and
  * %GTK_STATE_FLAG_INCONSISTENT whether it should be marked as undefined.
@@ -1115,7 +1115,7 @@ gtk_do_render_expander (GtkStyleContext *context,
  *
  * Renders an expander (as used in #GtkTreeView and #GtkExpander) in the area
- * defined by @x, @y, @width, @height. The state %GTK_STATE_FLAG_ACTIVE
+ * defined by @x, @y, @width, @height. The state %GTK_STATE_FLAG_CHECKED
  * determines whether the expander is collapsed or expanded.
  *
@@ -2163,7 +2163,7 @@ gtk_do_render_activity (GtkStyleContext *context,
  *
  * Renders an activity indicator (such as in #GtkSpinner).
- * The state %GTK_STATE_FLAG_ACTIVE determines whether there is
+ * The state %GTK_STATE_FLAG_CHECKED determines whether there is
  * activity going on.
  *


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]